==> knative-model-5.1.2-sources.jar: io/fabric8/knative/messaging/v1/InMemoryChannelStatusFluent.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReference;
import java.lang.Deprecated;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatusBuilder;
import java.util.Iterator;
import java.util.List;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatusFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceBuilder;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableBuilder;
import java.lang.Long;
import io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface InMemoryChannelStatusFluent<A extends InMemoryChannelStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAddress instead.
 * @return The buildable object.
 */
@Deprecated public Addressable getAddress();
    public Addressable buildAddress();
    public A withAddress(Addressable address);
    public Boolean hasAddress();
    public A withNewAddress(String url);
    public InMemoryChannelStatusFluent.AddressNested<A> withNewAddress();
    public InMemoryChannelStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
    public InMemoryChannelStatusFluent.AddressNested<A> editAddress();
    public InMemoryChannelStatusFluent.AddressNested<A> editOrNewAddress();
    public InMemoryChannelStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
    public A addToAnnotations(String key,String value);
    public A addToAnnotations(Map<String,String> map);
    public A removeFromAnnotations(String key);
    public A removeFromAnnotations(Map<String,String> map);
    public Map<String,String> getAnnotations();
    public A withAnnotations(Map<String,String> annotations);
    public Boolean hasAnnotations();
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public InMemoryChannelStatusFluent.ConditionsNested<A> addNewCondition();
    public InMemoryChannelStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public InMemoryChannelStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public InMemoryChannelStatusFluent.ConditionsNested<A> editCondition(int index);
    public InMemoryChannelStatusFluent.ConditionsNested<A> editFirstCondition();
    public InMemoryChannelStatusFluent.ConditionsNested<A> editLastCondition();
    public InMemoryChannelStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildDeadLetterChannel instead.
 * @return The buildable object.
 */
@Deprecated public KReference getDeadLetterChannel();
    public KReference buildDeadLetterChannel();
    public A withDeadLetterChannel(KReference deadLetterChannel);
    public Boolean hasDeadLetterChannel();
    public A withNewDeadLetterChannel(String apiVersion,String kind,String name,String namespace);
    public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> withNewDeadLetterChannel();
    public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> withNewDeadLetterChannelLike(KReference item);
    public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> editDeadLetterChannel();
    public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> editOrNewDeadLetterChannel();
    public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> editOrNewDeadLetterChannelLike(KReference item);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A withNewObservedGeneration(String arg1);
    public A withNewObservedGeneration(long arg1);
    public A addToSubscribers(int index,SubscriberStatus item);
    public A setToSubscribers(int index,SubscriberStatus item);
    public A addToSubscribers(SubscriberStatus... items);
    public A addAllToSubscribers(Collection<SubscriberStatus> items);
    public A removeFromSubscribers(SubscriberStatus... items);
    public A removeAllFromSubscribers(Collection<SubscriberStatus> items);
    public A removeMatchingFromSubscribers(Predicate<SubscriberStatusBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildSubscribers instead.
 * @return The buildable object.
 */
@Deprecated public List<SubscriberStatus> getSubscribers();
    public List<SubscriberStatus> buildSubscribers();
    public SubscriberStatus buildSubscriber(int index);
    public SubscriberStatus buildFirstSubscriber();
    public SubscriberStatus buildLastSubscriber();
    public SubscriberStatus buildMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
    public Boolean hasMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
    public A withSubscribers(List<SubscriberStatus> subscribers);
    public A withSubscribers(SubscriberStatus... subscribers);
    public Boolean hasSubscribers();
    public A addNewSubscriber(String message,Long observedGeneration,String ready,String uid);
    public InMemoryChannelStatusFluent.SubscribersNested<A> addNewSubscriber();
    public InMemoryChannelStatusFluent.SubscribersNested<A> addNewSubscriberLike(SubscriberStatus item);
    public InMemoryChannelStatusFluent.SubscribersNested<A> setNewSubscriberLike(int index,SubscriberStatus item);
    public InMemoryChannelStatusFluent.SubscribersNested<A> editSubscriber(int index);
    public InMemoryChannelStatusFluent.SubscribersNested<A> editFirstSubscriber();
    public InMemoryChannelStatusFluent.SubscribersNested<A> editLastSubscriber();
    public InMemoryChannelStatusFluent.SubscribersNested<A> editMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
    public interface AddressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AddressableFluent<InMemoryChannelStatusFluent.AddressNested<N>> {

            public N and();
            public N endAddress();    }


    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<InMemoryChannelStatusFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


    public interface DeadLetterChannelNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KReferenceFluent<InMemoryChannelStatusFluent.DeadLetterChannelNested<N>> {

            public N and();
            public N endDeadLetterChannel();    }


    public interface SubscribersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubscriberStatusFluent<InMemoryChannelStatusFluent.SubscribersNested<N>> {

            public N and();
            public N endSubscriber();    }


}

==> knative-model-5.3.0-sources.jar: io/fabric8/knative/messaging/v1/InMemoryChannelStatusFluent.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReference;
import java.lang.Deprecated;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatusBuilder;
import java.util.Iterator;
import java.util.List;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatusFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceBuilder;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableBuilder;
import java.lang.Long;
import io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface InMemoryChannelStatusFluent<A extends InMemoryChannelStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAddress instead.
 * @return The buildable object.
 */
@Deprecated public Addressable getAddress();
    public Addressable buildAddress();
    public A withAddress(Addressable address);
    public Boolean hasAddress();
    public A withNewAddress(String url);
    public InMemoryChannelStatusFluent.AddressNested<A> withNewAddress();
    public InMemoryChannelStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
    public InMemoryChannelStatusFluent.AddressNested<A> editAddress();
    public InMemoryChannelStatusFluent.AddressNested<A> editOrNewAddress();
    public InMemoryChannelStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
    public A addToAnnotations(String key,String value);
    public A addToAnnotations(Map<String,String> map);
    public A removeFromAnnotations(String key);
    public A removeFromAnnotations(Map<String,String> map);
    public Map<String,String> getAnnotations();
    public <K extends Object,V extends Object>A withAnnotations(Map<String,String> annotations);
    public Boolean hasAnnotations();
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public InMemoryChannelStatusFluent.ConditionsNested<A> addNewCondition();
    public InMemoryChannelStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public InMemoryChannelStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public InMemoryChannelStatusFluent.ConditionsNested<A> editCondition(int index);
    public InMemoryChannelStatusFluent.ConditionsNested<A> editFirstCondition();
    public InMemoryChannelStatusFluent.ConditionsNested<A> editLastCondition();
    public InMemoryChannelStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildDeadLetterChannel instead.
 * @return The buildable object.
 */
@Deprecated public KReference getDeadLetterChannel();
    public KReference buildDeadLetterChannel();
    public A withDeadLetterChannel(KReference deadLetterChannel);
    public Boolean hasDeadLetterChannel();
    public A withNewDeadLetterChannel(String apiVersion,String kind,String name,String namespace);
    public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> withNewDeadLetterChannel();
    public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> withNewDeadLetterChannelLike(KReference item);
    public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> editDeadLetterChannel();
    public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> editOrNewDeadLetterChannel();
    public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> editOrNewDeadLetterChannelLike(KReference item);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A withNewObservedGeneration(long arg1);
    public A addToSubscribers(int index,SubscriberStatus item);
    public A setToSubscribers(int index,SubscriberStatus item);
    public A addToSubscribers(SubscriberStatus... items);
    public A addAllToSubscribers(Collection<SubscriberStatus> items);
    public A removeFromSubscribers(SubscriberStatus... items);
    public A removeAllFromSubscribers(Collection<SubscriberStatus> items);
    public A removeMatchingFromSubscribers(Predicate<SubscriberStatusBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildSubscribers instead.
 * @return The buildable object.
 */
@Deprecated public List<SubscriberStatus> getSubscribers();
    public List<SubscriberStatus> buildSubscribers();
    public SubscriberStatus buildSubscriber(int index);
    public SubscriberStatus buildFirstSubscriber();
    public SubscriberStatus buildLastSubscriber();
    public SubscriberStatus buildMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
    public Boolean hasMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
    public A withSubscribers(List<SubscriberStatus> subscribers);
    public A withSubscribers(SubscriberStatus... subscribers);
    public Boolean hasSubscribers();
    public A addNewSubscriber(String message,Long observedGeneration,String ready,String uid);
    public InMemoryChannelStatusFluent.SubscribersNested<A> addNewSubscriber();
    public InMemoryChannelStatusFluent.SubscribersNested<A> addNewSubscriberLike(SubscriberStatus item);
    public InMemoryChannelStatusFluent.SubscribersNested<A> setNewSubscriberLike(int index,SubscriberStatus item);
    public InMemoryChannelStatusFluent.SubscribersNested<A> editSubscriber(int index);
    public InMemoryChannelStatusFluent.SubscribersNested<A> editFirstSubscriber();
    public InMemoryChannelStatusFluent.SubscribersNested<A> editLastSubscriber();
    public InMemoryChannelStatusFluent.SubscribersNested<A> editMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
    public interface AddressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AddressableFluent<InMemoryChannelStatusFluent.AddressNested<N>> {

            public N and();
            public N endAddress();    }


    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<InMemoryChannelStatusFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


    public interface DeadLetterChannelNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KReferenceFluent<InMemoryChannelStatusFluent.DeadLetterChannelNested<N>> {

            public N and();
            public N endDeadLetterChannel();    }


    public interface SubscribersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubscriberStatusFluent<InMemoryChannelStatusFluent.SubscribersNested<N>> {

            public N and();
            public N endSubscriber();    }


}
